import { fail } from '@sveltejs/kit';
import type { RequestHandler } from './$types';

const parseFile = async (file: Blob) => {
	const fileSize = file.size;
	const chunkSize = 4000;
	const chunks = Math.ceil(fileSize / chunkSize);
	const convoArray: string[] = [];
	const decoder = new TextDecoder();

	for (let i = 0; i < chunks; i++) {
		const start = i * chunkSize;
		const end = Math.min(start + chunkSize, fileSize);
		const buffer = await file.slice(start, end).arrayBuffer();
		const text = decoder.decode(buffer);
		convoArray.push(text);
	}
	return convoArray;
};

export const POST = (async ({ request, url }) => {
	try {
		const data = Object.fromEntries(await request.formData());
		const file = data.file as Blob;
		const conversation = await parseFile(file);

		return new Response(JSON.stringify(conversation), {
			headers: {
				'Content-Type': 'application/json'
			}
		});
	} catch (err) {
		throw fail(500, { err: err });
	}
}) satisfies RequestHandler;
